diff --git a/modules_k/perl/Makefile b/modules_k/perl/Makefile
index 190aa85..413ec9e 100644
--- a/modules_k/perl/Makefile
+++ b/modules_k/perl/Makefile
@@ -50,27 +50,27 @@ openserxs.c: openserxs.xs typemap
 perlpod: doc/perl_pod.sgml
 
 doc/perl_pod.sgml: openserxs.xs
-	cat $(PODFILES) | pod2docbook --doctype=chapter --title='OpenSER Perl API' --no-header - doc/perl_pod.sgml
+	cat $(PODFILES) | pod2docbook --doctype=chapter --title='Kamailio Perl API' --no-header - doc/perl_pod.sgml
 
 install-perl-scripts:
-	echo "installing Perl Kamailio (OpenSER) packages ..."
+	echo "installing Perl Kamailio (Kamailio) packages ..."
 	mkdir -p $(modules_prefix)/$(lib_dir)/perl
 	$(INSTALL_CFG) lib/perl/*.pm $(modules_prefix)/$(lib_dir)/perl
-	mkdir -p $(modules_prefix)/$(lib_dir)/perl/OpenSER
-	$(INSTALL_CFG) lib/perl/OpenSER/*.pm \
-		$(modules_prefix)/$(lib_dir)/perl/OpenSER
-	mkdir -p $(modules_prefix)/$(lib_dir)/perl/OpenSER/LDAPUtils
-	$(INSTALL_CFG) lib/perl/OpenSER/LDAPUtils/*.pm \
-		$(modules_prefix)/$(lib_dir)/perl/OpenSER/LDAPUtils
-	mkdir -p $(modules_prefix)/$(lib_dir)/perl/OpenSER/Utils
-	$(INSTALL_CFG) lib/perl/OpenSER/Utils/*.pm \
-		$(modules_prefix)/$(lib_dir)/perl/OpenSER/Utils
-	mkdir -p $(modules_prefix)/$(lib_dir)/perl/OpenSER/VDB
-	$(INSTALL_CFG) lib/perl/OpenSER/VDB/*.pm \
-		$(modules_prefix)/$(lib_dir)/perl/OpenSER/VDB
-	mkdir -p $(modules_prefix)/$(lib_dir)/perl/OpenSER/VDB/Adapter
-	$(INSTALL_CFG) lib/perl/OpenSER/VDB/Adapter/*.pm \
-		$(modules_prefix)/$(lib_dir)/perl/OpenSER/VDB/Adapter
+	mkdir -p $(modules_prefix)/$(lib_dir)/perl/Kamailio
+	$(INSTALL_CFG) lib/perl/Kamailio/*.pm \
+		$(modules_prefix)/$(lib_dir)/perl/Kamailio
+	mkdir -p $(modules_prefix)/$(lib_dir)/perl/Kamailio/LDAPUtils
+	$(INSTALL_CFG) lib/perl/Kamailio/LDAPUtils/*.pm \
+		$(modules_prefix)/$(lib_dir)/perl/Kamailio/LDAPUtils
+	mkdir -p $(modules_prefix)/$(lib_dir)/perl/Kamailio/Utils
+	$(INSTALL_CFG) lib/perl/Kamailio/Utils/*.pm \
+		$(modules_prefix)/$(lib_dir)/perl/Kamailio/Utils
+	mkdir -p $(modules_prefix)/$(lib_dir)/perl/Kamailio/VDB
+	$(INSTALL_CFG) lib/perl/Kamailio/VDB/*.pm \
+		$(modules_prefix)/$(lib_dir)/perl/Kamailio/VDB
+	mkdir -p $(modules_prefix)/$(lib_dir)/perl/Kamailio/VDB/Adapter
+	$(INSTALL_CFG) lib/perl/Kamailio/VDB/Adapter/*.pm \
+		$(modules_prefix)/$(lib_dir)/perl/Kamailio/VDB/Adapter
 
 install-scripts: install-perl-scripts
 
diff --git a/modules_k/perl/lib/perl/OpenSER.pm b/modules_k/perl/lib/perl/OpenSER.pm
deleted file mode 100644
index 5724501..0000000
--- a/modules_k/perl/lib/perl/OpenSER.pm
+++ /dev/null
@@ -1,51 +0,0 @@
-#
-# $Id$
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2006 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-package OpenSER;
-require Exporter;
-require DynaLoader;
-
-@ISA = qw(Exporter DynaLoader);
-@EXPORT = qw ( t );
-@EXPORT_OK = qw ( log );
-
-use OpenSER::Message;
-use OpenSER::Constants;
-use OpenSER::Utils::Debug;
-
-bootstrap OpenSER;
-
-
-BEGIN {
-	$SIG{'__DIE__'} = sub {
-		OpenSER::Message::log(undef, L_ERR, "perl error: $_[0]\n");
-        };
-	$SIG{'__WARN__'} = sub {
-		OpenSER::Message::log(undef, L_ERR, "perl warning: $_[0]\n");
-        };
-}
-
-1;
-
diff --git a/modules_k/perl/lib/perl/OpenSER/Constants.pm b/modules_k/perl/lib/perl/OpenSER/Constants.pm
deleted file mode 100644
index 55af44f..0000000
--- a/modules_k/perl/lib/perl/OpenSER/Constants.pm
+++ /dev/null
@@ -1,212 +0,0 @@
-#
-# $Id$
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2006 Collax GmbH
-#		     (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-=head1 OpenSER::Constants
-
-This package provides a number of constants taken from enums and defines of
-OpenSER header files. Unfortunately, there is no mechanism for updating the
-constants automatically, so check the values if you are in doubt.
-
-=cut
-
-package OpenSER::Constants;
-
-use Exporter;
-
-# Constants from route_struct.h
-
-our @ISA = qw(Exporter);
-
-our @EXPORT;
-
-BEGIN {
-
-	sub const {
-		my $c = shift;
-		my $v = shift;
-
-		eval "use constant $c => $v";
-
-		push(@EXPORT, $c);
-	}
-
-###########################################################
-## Unfortunately, there are no "enum"s in Perl. The following blocks reflect
-## some C headers from OpenSER.
-## UPDATE THIS FILE WHEN THESE HEADER FILES CHANGE!
-
-#####################
-# From parse_fline.h
-	const( SIP_REQUEST	=> 1);
-	const( SIP_REPLY	=> 2);
-	const( SIP_INVALID	=> 0);
-
-#####################
-# From route_struct.h
-
-	const( EXP_T	=> 1);
-	const( ELEM_T	=> 2);
-
-
-	const( AND_OP	=> 1);
-	const( OR_OP	=> 2);
-	const( NOT_OP	=> 3);
-
-
-	const( EQUAL_OP	=> 10);
-	const( MATCH_OP	=> 11);
-	const( GT_OP	=> 12);
-	const( LT_OP	=> 13);
-	const( GTE_OP	=> 14);
-	const( LTE_OP	=> 15);
-	const( DIFF_OP	=> 16);
-	const( NO_OP	=> 17);
-
-
-	const( METHOD_O		=> 1);
-	const( URI_O		=> 2);
-	const( FROM_URI_O	=> 3);
-	const( TO_URI_O		=> 4);
-	const( SRCIP_O		=> 5);
-	const( SRCPORT_O	=> 6);
-	const( DSTIP_O		=> 7);
-	const( DSTPORT_O	=> 9);
-	const( PROTO_O		=> 9);
-	const( AF_O		=> 10);
-	const( MSGLEN_O		=> 11);
-	const( DEFAULT_O	=> 12);
-	const( ACTION_O		=> 13);
-	const( NUMBER_O		=> 14);
-	const( RETCODE_O	=> 15);
-
-
-	const( FORWARD_T		=> 1);
-	const( SEND_T			=> 2);
-	const( DROP_T			=> 3);
-	const( LOG_T			=> 4);
-	const( ERROR_T			=> 5);
-	const( ROUTE_T			=> 6);
-	const( EXEC_T			=> 7);
-	const( SET_HOST_T		=> 8);
-	const( SET_HOSTPORT_T		=> 9);
-	const( SET_USER_T		=> 10);
-	const( SET_USERPASS_T		=> 11);
-	const( SET_PORT_T		=> 12);
-	const( SET_URI_T		=> 13);
-	const( IF_T			=> 14);
-	const( MODULE_T			=> 15);
-	const( SETFLAG_T		=> 16);
-	const( RESETFLAG_T		=> 17);
-	const( ISFLAGSET_T 		=> 18);
-	const( LEN_GT_T			=> 19);
-	const( PREFIX_T			=> 20);
-	const( STRIP_T			=> 21);
-	const( STRIP_TAIL_T		=> 22);
-	const( APPEND_BRANCH_T		=> 23);
-	const( REVERT_URI_T		=> 24);
-	const( FORCE_RPORT_T		=> 25);
-	const( FORCE_LOCAL_RPORT_T	=> 26);
-	const( SET_ADV_ADDR_T		=> 27);
-	const( SET_ADV_PORT_T		=> 28);
-	const( FORCE_TCP_ALIAS_T	=> 29);
-	const( FORCE_SEND_SOCKET_T	=> 30);
-	const( SERIALIZE_BRANCHES_T	=> 31);
-	const( NEXT_BRANCHES_T		=> 32);
-	const( RETURN_T			=> 33);
-	const( EXIT_T			=> 34);
-	const( SWITCH_T			=> 35);
-	const( CASE_T			=> 36);
-	const( DEFAULT_T		=> 37);
-	const( SBREAK_T			=> 38);
-	const( SET_DSTURI_T		=> 39);
-	const( RESET_DSTURI_T		=> 40);
-	const( ISDSTURISET_T		=> 41);
-
-
-	const( NOSUBTYPE	=> 0);
-	const( STRING_ST	=> 1);
-	const( NET_ST		=> 2);
-	const( NUMBER_ST	=> 3);
-	const( IP_ST		=> 4);
-	const( RE_ST		=> 5);
-	const( PROXY_ST		=> 6);
-	const( EXPR_ST		=> 7);
-	const( ACTIONS_ST	=> 8);
-	const( CMD_ST		=> 9);
-	const( MODFIXUP_ST	=> 10);
-	const( MYSELF_ST	=> 11);
-	const( STR_ST		=> 12);
-	const( SOCKID_ST	=> 13);
-	const( SOCKETINFO_ST	=> 14);
-
-
-#####################
-# non-enum constants from dprint.h:
-# Logging levels
-	const( L_ALERT	=> -3);
-	const( L_CRIT	=> -2);
-	const( L_ERR	=> -1);
-	const( L_WARN	=> 1);
-	const( L_NOTICE	=> 2);
-	const( L_INFO	=> 3);
-	const( L_DBG	=> 4);
-
-
-#####################
-# From flags.h:
-# Flags for setflag et.al
-	const( FL_WHITE		=> 1);
-	const( FL_YELLOW	=> 2);
-	const( FL_GREEN		=> 3);
-	const( FL_RED		=> 4);
-	const( FL_BLUE		=> 5);
-	const( FL_MAGENTA	=> 6);
-	const( FL_BROWN		=> 7);
-	const( FL_BLACK		=> 8);
-	const( FL_ACC		=> 9);
-	const( FL_MAX		=> 10);
-
-
-#####################
-# From db/db_val.h:
-# Value types for virtual database classes
-	const( DB_INT		=> 0 );
-	const( DB_DOUBLE	=> 1 );
-	const( DB_STRING	=> 2 );
-	const( DB_STR		=> 3 );
-	const( DB_DATETIME	=> 4 );
-	const( DB_BLOB		=> 5 );
-	const( DB_BITMAP	=> 6 );
-
-
-#####################
-# For VDB call types
-	const( VDB_CALLTYPE_FUNCTION_SINGLE	=> 0 );
-	const( VDB_CALLTYPE_FUNCTION_MULTI	=> 0 );
-	const( VDB_CALLTYPE_METHOD		=> 1 );
-
-}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/LDAPUtils/LDAPConf.pm b/modules_k/perl/lib/perl/OpenSER/LDAPUtils/LDAPConf.pm
deleted file mode 100644
index 0654a67..0000000
--- a/modules_k/perl/lib/perl/OpenSER/LDAPUtils/LDAPConf.pm
+++ /dev/null
@@ -1,186 +0,0 @@
-#
-# $Id$
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2006 Collax GmbH 
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-# This file was kindly donated by Collax GmbH
-
-=head1 OpenSER::LDAPUtils::LDAPConf
-
-OpenSER::LDAPUtils::LDAPConf - Read openldap config from standard config files.
-
- use OpenSER::LDAPUtils::LDAPConf;
- my $conf = new OpenSER::LDAPUtils::LDAPConf();
-
-This module may be used to retrieve the global LDAP configuration as
-used by other LDAP software, such as C<nsswitch.ldap> and C<pam-ldap>.
-The configuration is usualy stored in C</etc/openldap/ldap.conf> 
-
-When used from an account with sufficient privilegs (e.g. root), the
-ldap manager passwort is also retrieved.
-
-=cut
-package OpenSER::LDAPUtils::LDAPConf;
-
-my $def_ldap_path = "/etc/openldap" ;
-my $def_conf      = "ldap.conf";
-my $def_secret    = "ldap.secret";
-
-=head2 Constructor new()
-
-Returns a new, initialized C<OpenSER::LDAPUtils::LDAPConf> object.
-
-=cut
-sub new {
-  my $class = shift;
-
-  my $self  = _init( $def_ldap_path . "/" . $def_conf , 
-  		     $def_ldap_path . "/" . $def_secret);
-
-  if( ! $self ) { return undef; } ## can happen during customizing
-
-  bless $self , $class;
-
-  return $self;
-}
-
-
-sub _init {
-  my $conf_file   = shift;
-  my $secret_file = shift;
-
-  my $result = {};
-
-  if( open(LDAPCONF,"<$conf_file") ) {
-    while(<LDAPCONF>) {
-      chomp;
-      s/#.*$//;
-      if( m/^\s*$/ ) { next; }
-      my ($var,$val) = split(" ",$_,2);
-      
-      $result->{lc($var)} = $val;
-
-    }
-    close(LDAPCONF);
-  } else {
-    return undef;
-  }
-
-  if( -r $secret_file ) {
-    if( open(SECRET,"<$secret_file") ) {
-      my $secret = <SECRET>;
-      chomp $secret;
-      $result->{'rootbindpw'} = $secret;
-      close(SECRET);
-    }
-  }
-
-  return $result;
-}
-
-=head2 Method base()
-
-Returns the servers base-dn to use when doing queries.
-
-=cut
-sub base { return $_[0]->{'base'}; }
-
-=head2 Method host()
-
-Returns the ldap host to contact.
-
-=cut
-sub host { return $_[0]->{'host'}; }
-
-
-=head2 Method port()
-
-Returns the ldap servers port.
-
-=cut
-sub port { return $_[0]->{'port'}; }
-
-=head2 Method uri()
-
-Returns an uri to contact the ldap server. When there is no ldap_uri in
-the configuration file, an C<ldap:> uri is constucted from host and port.
-
-=cut
-sub uri {
-    my $self = shift;
-
-    if( $self->{'ldap_uri'} ) { return $self->{'ldap_uri'}; }
-
-    return "ldap://" . $self->host . ":" . $self->port ;
-
-}
-
-=head2 Method rootbindpw()
-
-Returns the ldap "root" password.
-
-Note that the C<rootbindpw> is only available when the current account has
-sufficient privilegs to access C</etc/openldap/ldap.secret>.
-
-=cut
-sub rootbindpw { return $_[0]->{'rootbindpw'}; }
-
-=head2 Method rootbinddn()
-
-Returns the DN to use for "root"-access to the ldap server.
-
-=cut
-sub rootbinddn { return $_[0]->{'rootbinddn'}; }
-
-=head2 Method binddn()
-
-Returns the DN to use for authentication to the ldap server. When no
-bind dn has been specified in the configuration file, returns the
-C<rootbinddn>.
-
-=cut
-sub binddn { 
-    my $self = shift;
-
-    if( $self->{'binddn'} ) { return $self->{'binddn'}; }
-    return $self->rootbinddn;
-}
-
-=head2 Method bindpw()
-
-Returns the password to use for authentication to the ldap server. When no
-bind password has been specified, returns the C<rootbindpw> if any.
-
-=cut
-sub bindpw { 
-    my $self = shift;
-
-    if( $self->{'bindpw'} ) { return $self->{'bindpw'}; }
-    return $self->rootbindpw;
-}
-
-
-
-
-1;
-
diff --git a/modules_k/perl/lib/perl/OpenSER/LDAPUtils/LDAPConnection.pm b/modules_k/perl/lib/perl/OpenSER/LDAPUtils/LDAPConnection.pm
deleted file mode 100644
index b51d0fc..0000000
--- a/modules_k/perl/lib/perl/OpenSER/LDAPUtils/LDAPConnection.pm
+++ /dev/null
@@ -1,238 +0,0 @@
-#
-# $Id$
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2006 Collax GmbH
-#		     (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-# This file was kindly donated by Collax GmbH
-
-=head1 OpenSER::LDAPUtils::LDAPConnection
-
-OpenSER::LDAPUtils::LDAPConnection - Perl module to perform simple LDAP queries.
-
-OO-Style interface:
-
-  use OpenSER::LDAPUtils::LDAPConnection;
-  my $ldap = new OpenSER::LDAPUtils::LDAPConnection;
-  my @rows = $ldap-search("uid=andi","ou=people,ou=coreworks,ou=de");
-
-Procedural interface:
-
-  use OpenSER::LDAPUtils::LDAPConnection;
-  my @rows = $ldap->search(
-  	new OpenSER::LDAPUtils::LDAPConfig(), "uid=andi","ou=people,ou=coreworks,ou=de");
-
-This perl module offers a somewhat simplified interface to the C<Net::LDAP>
-functionality. It is intended for cases where just a few attributes should
-be retrieved without the overhead of the full featured C<Net::LDAP>.
-
-=cut
-
-package OpenSER::LDAPUtils::LDAPConnection;
-
-use OpenSER::LDAPUtils::LDAPConf;
-use Net::LDAP;
-use Authen::SASL;
-use UNIVERSAL qw( isa );
-
-my $ldap_singleton = undef;
-
-
-=head2 Constructor new( [config, [authenticated]] )
-
-Set up a new LDAP connection.
-
-The first argument, when given, should be a hash reference pointing
-to to the connection parameters, possibly an C<OpenSER::LDAPUtils::LDAPConfig>
-object. This argument may be C<undef> in which case a new (default)
-C<OpenSER::LDAPUtils::LDAPConfig> object is used.
-
-When the optional second argument is a true value, the connection
-will be authenticated. Otherwise an anonymous bind is done.
-
-On success, a new C<LDAPConnection> object is returned, otherwise
-the result is C<undef>.
-
-=cut
-sub new {
-    my $class    = shift;
-    my $conf     = shift;
-    my $doauth   = shift;
-
-    if( ! defined( $conf ) ) {
-      $conf = new OpenSER::LDAPUtils::LDAPConf();
-    }
-
-    #print STDERR "new ldap checks\n";
-    my $self = {
-    	conf => $conf,
-    };
-
-    bless $self, $class;
-
-    #
-    # connect to ldap server and do an anonymous bind
-    #
-    $self->{'ldap'} = Net::LDAP->new( $self->conf->uri() );
-    
-    # return undef if ldap connection failed
-    if( ! $self->ldap ) {
-       print STDERR "Could not connect to LDAP server.\n";
-       return undef;
-    }
-
-    if( ! $doauth ) {
-      $self->ldap->bind ;    # an anonymous bind
-    } else {
-
-      if( $self->conf->uri && ( $self->conf->uri =~ m/^ldapi:/ ) ) {
-
-        my $sasl = new Authen::SASL( mechanism => 'EXTERNAL ANONYMOUS');
-	$self->ldap->bind($self->conf->binddn, sasl => $sasl );
-
-      } else {
-	# only simple binds for now.
-	$self->ldap->bind($self->conf->binddn,
-				password => $self->conf->bindpw);
-      }
-
-    }
-    
-    return $self;
-};
-
-sub DESTROY {
-    my $self = shift;
-    if( $self->ldap ) {
-        $self->ldap->unbind();
-        delete $self->{'ldap'};
-    }
-}
-
-sub conf { return $_[0]->{'conf'}; }
-sub ldap { return $_[0]->{'ldap'}; }
-
-=head2 Function/Method search( conf, filter, base, [requested_attributes ...])
-
-perform an ldap search, return the dn of the first matching
-directory entry, unless a specific attribute has been requested,
-in wich case the values(s) fot this attribute are returned.
-
-When the first argument (conf) is a C<OpenSER::LDAPUtils::LDAPConnection>, it
-will be used to perform the queries. You can pass the first argument 
-implicitly by using the "method" syntax.
-
-Otherwise the C<conf> argument should be a reference to a hash 
-containing the connection setup parameters as contained in a 
-C<OpenSER::LDAPUtils::LDAPConf> object. In this mode, the
-C<OpenSER::LDAPUtils::LDAPConnection> from previous queries will be reused.
-
-=head3 Arguments:
-
-=over 12
-
-=item conf
-
-configuration object, used to find host,port,suffix and use_ldap_checks
-
-=item filter
-
-ldap search filter, eg '(mail=some@domain)' 
-
-=item base
-
-search base for this query. If undef use default suffix,
-concat base with default suffix if the last char is a ','
-
-=item requested_attributes
-
-retrieve the given attributes instead of the dn from the ldap directory. 
-
-=back
-
-=head3 Result:
-
-Without any specific C<requested_attributes>, return the dn of all matching
-entries in the LDAP directory.
-
-When some C<requested_attributes> are given, return an array with those
-attibutes. When multiple entries match the query, the attribute lists
-are concatenated.
-
-=cut
-sub search {
-
-    my $conf = shift;
-
-    my $ldap = undef;
-
-    if( isa($conf ,"OpenSER::LDAPUtils::LDAPConnection") ) {
-      $ldap = $conf;
-    } else {
-      if( ! $ldap_singleton ) {
-        $ldap_singleton = new OpenSER::LDAPUtils::LDAPConnection($conf);
-      }
-      return undef unless $ldap_singleton;
-      $ldap = $ldap_singleton;
-    }
-
-
-    my $filter         = shift;
-    my $base           = shift;
-    my @requested_attr = @_ ;
-
-    if( ! $base ) {
-        $base = $ldap->conf->base;
-    } elsif ( substr($base,-1) eq ',' ) {
-        $base .= $ldap->conf->base;
-    }
-
-    my @search_extra = ();
-    if( @requested_attr ) {
-        push @search_extra , 'attrs' => [ @requested_attr ];
-    }
-
-    my $mesg = $ldap->ldap->search (
-                               base      => $base,
-                               filter    => $filter,
-                               #sizelimit => 100 ,
-                               @search_extra
-                             );
-
-
-    if( $mesg->is_error ) { warn $mesg->error; return undef };
-
-    my @result=();
-    my $max_entries=$mesg->count;
-    my $i;
-    for($i = 0 ; $i < $max_entries ; $i++) {
-        my $entry = $mesg->entry($i);
-        foreach my $attr (@requested_attr) {
-            push @result, $entry->get_value($attr);
-        } 
-    }
- 
-    return @result;
-}
-
-1;
-
diff --git a/modules_k/perl/lib/perl/OpenSER/Message.pm b/modules_k/perl/lib/perl/OpenSER/Message.pm
deleted file mode 100644
index 9de1035..0000000
--- a/modules_k/perl/lib/perl/OpenSER/Message.pm
+++ /dev/null
@@ -1,59 +0,0 @@
-#
-# $Id$
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2006 Collax GmbH
-#		     (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-package OpenSER::Message;
-require Exporter;
-require DynaLoader;
-
-our @ISA = qw(Exporter DynaLoader);
-our @EXPORT = qw ( t );
-bootstrap OpenSER;
-
-sub AUTOLOAD{
-	use vars qw($AUTOLOAD);
-	my $a = $AUTOLOAD;
-	
-	$a =~ s/^OpenSER::Message:://;
-
-	my $l = scalar @_;
-	if ($l == 0) {
-		croak("Usage: $a(self, param1 = undef, param2 = undef)");
-	} elsif ($l == 1) {
-		return OpenSER::Message::moduleFunction(@_[0], $a);
-	} elsif ($l == 2) {
-		return OpenSER::Message::moduleFunction(@_[0], $a, @_[1]);
-	} elsif ($l == 3) {
-		return OpenSER::Message::moduleFunction(@_[0],
-							$a, @_[1], @_[2]);
-	} else {
-		croak("Usage: $a(self, param1 = undef, param2 = undef)");
-	}
-
-}
-
-sub DESTROY {}
-
-1;
-
diff --git a/modules_k/perl/lib/perl/OpenSER/Utils/Debug.pm b/modules_k/perl/lib/perl/OpenSER/Utils/Debug.pm
deleted file mode 100644
index 59d85d5..0000000
--- a/modules_k/perl/lib/perl/OpenSER/Utils/Debug.pm
+++ /dev/null
@@ -1,36 +0,0 @@
-#
-# $Id: Debug.pm 757 2007-01-05 10:56:28Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2007 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-package OpenSER::Utils::Debug;
-
-use OpenSER qw ( log );
-use OpenSER::Constants;
-
-#sub DESTROY {
-#	my $class = shift;
-#	OpenSER::log(OpenSER::Constants::L_CRIT, "perl/vdb:Debug:Dying object: $class\n");
-#}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/Utils/PhoneNumbers.pm b/modules_k/perl/lib/perl/OpenSER/Utils/PhoneNumbers.pm
deleted file mode 100644
index 91dcca8..0000000
--- a/modules_k/perl/lib/perl/OpenSER/Utils/PhoneNumbers.pm
+++ /dev/null
@@ -1,175 +0,0 @@
-#
-# $Id$
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2006 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-# This file was kindly donated by Collax GmbH
-
-
-=head1 OpenSER::Utils::PhoneNumbers
-
-OpenSER::Utils::PhoneNumbers - Functions for canonical forms of phone numbers.
-
- use OpenSER::Utils::PhoneNumbers;
-
- my $phonenumbers = new OpenSER::Utils::PhoneNumbers(
-      publicAccessPrefix => "0",
-      internationalPrefix => "+",
-      longDistancePrefix => "0",
-      areaCode => "761",
-      pbxCode => "456842",
-      countryCode => "49"
-    );
-					
- $canonical = $phonenumbers->canonicalForm("07612034567");
- $number    = $phonenumbers->dialNumber("+497612034567");
-
-A telphone number starting with a plus sign and containing all dial prefixes 
-is in canonical form. This is usally not the number to dial at any location,
-so the dialing number depends on the context of the user/system.
-
-The idea to canonicalize numbers were taken from hylafax.
-
-Example: +497614514829 is the canonical form of my phone number, 829 is the 
-number to dial at Pyramid, 4514829 is the dialing number from Freiburg are and
-so on.
-
-To canonicalize any number, we strip off any dial prefix we find and 
-then add the prefixes for the location. So, when the user enters the
-number 04514829 in context pyramid, we remove the publicAccessPrefix 
-(at Pyramid this is 0) and the  pbxPrefix (4514 here). The result 
-is 829. Then we add all the general dial prefixes - 49 (country) 761 (area) 
-4514 (pbx) and 829, the number itself => +497614514829 
-
-To get the dialing number from a canonical phone number, we substract all
-general prefixes until we have something 
-
-As said before, the interpretation of a phone number depends on the context of
-the location. For the functions in this package, the context is created through
-the C<new> operator.
-
-The following fields should be set:
-
-      'longDistancePrefix' 
-      'areaCode'
-      'pbxCode' 
-      'internationalPrefix'
-      'publicAccessPrefix'
-      'countryCode'
-
-This module exports the following functions when C<use>ed:
-
-=cut
-
-package OpenSER::Utils::PhoneNumbers;
-
-use Exporter;
-our @ISA = qw(Exporter);
-our @EXPORT = qw(
-	     canonicalForm
-	     dialNumber
-	    );
-
-=head2 new(publicAccessPrefix,internationalPrefix,longDistancePrefix,countryCode,areaCode,pbxCode)
-
-The new operator returns an object of this type and sets its locational
-context according to the passed parameters. See
-L<OpenSER::Utils::PhoneNumbers> above.
-
-=cut
-
-sub new {
-	my $class = shift;
-	my %setup = @_;
-
-	my $self = {
-		PAPrefix => %setup->{'publicAccessPrefix'},
-		IDPrefix => %setup->{'internationalPrefix'},
-		LDPrefix => %setup->{'longDistancePrefix'},
-
-		Country => %setup->{'countryCode'},
-		Area => %setup->{'areaCode'},
-		PBX => %setup->{'pbxCode'}
-	};
-
-	bless $self, $class;
-
-	return $self;
-
-}
-
-=head2 canonicalForm( number [, context] )
-
-Convert a phone number (given as first argument) into its canonical form. When
-no context is passed in as the second argument, the default context from the
-systems configuration file is used.
-
-=cut
-sub canonicalForm {
-  my $self = shift;
-  my $number  = shift;
-
-  $number =~ s/[^+0-9]*//g;                         # strip white space etc.
-
-  if( $number =~ m/^[^+]/ ) {
-    $number =~ s/^$self->{'PAPrefix'}$self->{'IDPrefix'}/+/;                          # replace int. dialing code
-    if( $number =~ m/^[^+]/ ) {
-      $number =~ s/^$self->{'PAPrefix'}$->{'LDPrefix'}/+$self->{'Country'}/;                # long distance number
-      if( $number =~ m/^[^+]/ ) {
-        $number =~ s/^$self->{'PAPrefix'}/+$self->{'Country'}$self->{'Area'}/;                  # local number
-        if( $number =~ m/^[^+]/ ) {
-           $number =~ s/^(.*)/+$self->{'Country'}$self->{'Area'}$self->{PBX}$1/;              # else cononicalize
-	}
-      }
-    }
-  }
-  return $number;
-}
-
-=head2 dialNumber( number [, context] )
-
-Convert a canonical phone number (given in the first argument) into a number to
-to dial.  WHen no context is given in the second argument, a default context
-from the systems configuration is used.
-
-=cut
-sub dialNumber {
-	my $self = shift;
-	my $number  = shift;
-
-	$number =~ s/[^+0-9]+//g;											# strip syntactical sugar.
-	$number =~ s/^$self->{'PAPrefix'}$self->{'IDPrefix'}$self->{'Country'}$self->{'Area'}$self->{'PBX'}//;		# inhouse phone call
-	$number =~ s/^$self->{'PAPrefix'}$self->{'IDPrefix'}$self->{'Country'}$self->{'Area'}/$self->{'PAPrefix'}/;     # local phone call
-	$number =~ s/^$self->{'PAPrefix'}$self->{'LDPrefix'}$self->{'Area'}$self->{'PBX'}//;				# inhouse phone call
-	$number =~ s/^$self->{'PAPrefix'}$self->{'LDPrefix'}$self->{'Area'}/$self->{'PAPrefix'}/;			# local phone call
-	$number =~ s/^$self->{'PAPrefix'}$self->{'IDPrefix'}$self->{'Country'}/$self->{'PAPrefix'}$self->{'LDPrefix'}/; # long distance call
-	$number =~ s/^$self->{'PAPrefix'}$self->{'PBX'}//;								# inhouse call
-	$number =~ s/^[+]$self->{'Country'}$self->{'Area'}$self->{'PBX'}//;						# inhouse phone call
-	$number =~ s/^[+]$self->{'Country'}$self->{'Area'}/$self->{'PAPrefix'}/;					# local phone call
-	$number =~ s/^[+]$self->{'Country'}/$self->{'PAPrefix'}$self->{'LDPrefix'}/;					# long distance call
-	$number =~ s/^[+]/$self->{'PAPrefix'}$self->{'IDPrefix'}/;							# international call
-
-	return $number;
-}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/VDB.pm b/modules_k/perl/lib/perl/OpenSER/VDB.pm
deleted file mode 100644
index 419e5f9..0000000
--- a/modules_k/perl/lib/perl/OpenSER/VDB.pm
+++ /dev/null
@@ -1,160 +0,0 @@
-#
-# $Id: VDB.pm 757 2007-01-05 10:56:28Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2006 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-=head1 OpenSER::VDB
-
-This package is an (abstract) base class for all virtual databases. Derived
-packages can be configured to be used by OpenSER as a database.
-
-The base class itself should NOT be used in this context, as it does not
-provide any functionality.
-
-=cut
-
-package OpenSER::VDB;
-
-use OpenSER;
-use OpenSER::Constants;
-
-use OpenSER::VDB::Column;
-use OpenSER::VDB::Pair;
-use OpenSER::VDB::ReqCond;
-use OpenSER::VDB::Result;
-use OpenSER::VDB::Value;
-use OpenSER::VDB::VTab;
-
-use UNIVERSAL qw ( can );
-
-our @ISA = qw ( OpenSER::Utils::Debug );
-
-sub new {
-	my $class = shift;
-
-	my $self = {
-		tablename => undef,
-		vtabs => {}
-	};
-
-	bless $self, $class;
-
-	return $self;
-}
-
-sub use_table {
-	my $self = shift;
-	my $v = shift;
-	
-	$self->{tablename} = $v;
-
-	if ($v eq "version") {
-		# "version" table is handled individually. Don't initialize VTabs.
-		return 0;
-	}
-
-	if ($self->{vtabs}->{$v}) {
-		return 0;
-	}
-
-	if ($v =~ m/^((.*)::)?([\w_][\d\w_]*)$/) {
-		my $pkg;
-		if (!$2) {
-			$pkg = "main";
-		} else {
-			$pkg = $2;
-		}
-
-		OpenSER::log(L_DBG, "perlvdb:VDB: Setting VTab: v is $v (pkg is $pkg, func/method is $3)\n");
-
-		if (can($pkg, $3)) {
-			$self->{vtabs}->{$v} = new OpenSER::VDB::VTab( func => $pkg . "::" . $3);
-		} elsif (can($v, "init")) {
-			$v->init();
-			$self->{vtabs}->{$v} = new OpenSER::VDB::VTab( obj => $v );
-		} elsif (can($v, "new")) {
-			my $obj = $v->new();
-			$self->{vtabs}->{$v} = new OpenSER::VDB::VTab( obj => $obj );
-		} else {
-			OpenSER::log(L_ERR, "perlvdb:VDB: Invalid virtual table.\n");
-			return -1;
-		}
-	} else {
-		OpenSER::log(L_ERR, "perlvdb:VDB: Invalid virtual table.\n");
-		return -1;
-	}
-}
-
-sub _insert {
-	my $self = shift;
-	return $self->insert(@_);
-}
-
-sub _replace {
-	my $self = shift;
-	return $self->replace(@_);
-}
-
-sub _delete {
-	my $self = shift;
-	return $self->delete(@_);
-}
-
-sub _update {
-	my $self = shift;
-	return $self->update(@_);
-}
-
-sub _query {
-	my $self = shift;
-	return $self->query(@_);
-}
-
-
-
-sub insert {
-	OpenSER::log(L_INFO, "perlvdb:Insert not implemented in base class.\n");
-	return -1;
-}
-
-sub replace {
-	OpenSER::log(L_INFO, "perlvdb:Replace not implemented in base class.\n");
-	return -1;
-}
-
-sub delete {
-	OpenSER::log(L_INFO, "perlvdb:Delete not implemented in base class.\n");
-	return -1;
-}
-
-sub update {
-	OpenSER::log(L_INFO, "perlvdb:Update not implemented in base class.\n");
-	return -1;
-}
-
-sub query {
-	OpenSER::log(L_INFO, "perlvdb:Query not implemented in base class.\n");
-	return -1;
-}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/AccountingSIPtrace.pm b/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/AccountingSIPtrace.pm
deleted file mode 100644
index 8e0992a..0000000
--- a/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/AccountingSIPtrace.pm
+++ /dev/null
@@ -1,51 +0,0 @@
-#
-# $Id: AccountingSIPtrace.pm 757 2007-01-05 10:56:28Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2007 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-=head1 OpenSER::VDB::Adapter::AccountingSIPtrace
-
-This package is an Adapter for the acc and siptrace modules, featuring
-only an insert operation.
-
-=cut
-
-package OpenSER::VDB::Adapter::AccountingSIPtrace;
-
-use OpenSER::VDB;
-use OpenSER::VDB::VTab;
-use OpenSER;
-use OpenSER::Constants;
-use Data::Dumper;
-
-our @ISA = qw ( OpenSER::VDB );
-
-sub insert {
-	my $self = shift;
-	my $vals = shift;
-
-	my $vtab = $self->{vtabs}->{$self->{tablename}};
-	return $vtab->call("insert", $vals);
-}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/Alias.pm b/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/Alias.pm
deleted file mode 100644
index 4eeb070..0000000
--- a/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/Alias.pm
+++ /dev/null
@@ -1,98 +0,0 @@
-#
-# $Id: Alias.pm 757 2007-01-05 10:56:28Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2007 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-=head1 OpenSER::VDB::Adapter::Alias
-
-This package is intended for usage with the alias_db module. The query VTab
-has to take two arguments and return an array of two arguments (user name/domain).
-
-=cut
-
-package OpenSER::VDB::Adapter::Alias;
-
-use OpenSER::Constants;
-use OpenSER qw ( log );
-
-use OpenSER::VDB;
-use OpenSER::VDB::Column;
-use OpenSER::VDB::Result;
-
-use Data::Dumper;
-
-our @ISA = qw ( OpenSER::VDB );
-
-=head2 query(conds,retkeys,order)
-
-Queries the vtab with the given arguments for
-request conditions, keys to return and sort order column name.
-
-=cut
-
-sub query {
-	my $self = shift;
-
-	my $conds = shift;
-	my $retkeys = shift; # Unused value here.
-	my $order = shift; # Unused value here.
-
-	my @cols;
-	
-	my $alias_username = undef;
-	my $alias_domain = undef;
-	my $username;
-	my $domain;
-
-	for my $c (@$conds) {
-		if (($c->key() eq "alias_username") && ($c->op() eq "=")) {
-			$alias_username = $c->data();
-		}
-		if (($c->key() eq "alias_domain") && ($c->op() eq "=")) {
-			$alias_domain = $c->data();
-		}
-	}
-
-	my $vtab = $self->{vtabs}->{$self->{tablename}};
-	$newaddr = $vtab->call("query", $alias_username, $alias_domain);
-	
-	my $result;
-
-	push @cols, new OpenSER::VDB::Column(DB_STRING, "username");
-	push @cols, new OpenSER::VDB::Column(DB_STRING, "domain");
-
-	if ($newaddr) {
-		my @row;
-		my $resval1 = new OpenSER::VDB::Value(DB_STRING, $newaddr->{username} );
-		push @row, $resval1;
-		my $resval2 = new OpenSER::VDB::Value(DB_STRING, $newaddr->{domain} );
-		push @row, $resval2;
-		$result = new OpenSER::VDB::Result(\@cols, (bless \@row, "OpenSER::Utils::Debug"));
-	} else {
-		$result = new OpenSER::VDB::Result(\@cols);
-	}
-
-	return $result;
-}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/Auth.pm b/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/Auth.pm
deleted file mode 100644
index 3d8dd2d..0000000
--- a/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/Auth.pm
+++ /dev/null
@@ -1,94 +0,0 @@
-#
-# $Id: Auth.pm 757 2007-01-05 10:56:28Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2007 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-=head1 OpenSER::VDB::Adapter::Auth
-
-This adapter is intended for usage with the auth_db module.
-The VTab should take a username as an argument and return a (plain text!)
-password.
-
-=cut
-
-package OpenSER::VDB::Adapter::Auth;
-
-use OpenSER::Constants;
-use OpenSER qw ( log );
-
-use OpenSER::VDB;
-use OpenSER::VDB::Column;
-use OpenSER::VDB::Result;
-use OpenSER::VDB::Adapter::TableVersions;
-
-use Data::Dumper;
-
-our @ISA = qw ( OpenSER::VDB );
-
-sub query {
-	my $self = shift;
-
-	my $conds = shift;
-	my $retkeys = shift;
-	my $order = shift; # Unused value here.
-
-	my @cols;
-	
-	my $username = undef;
-	my $password = undef;
-
-	if ($self->{tablename} eq "version") {
-		return OpenSER::VDB::Adapter::TableVersions::version(@$conds[0]->data());
-	}
-		
-	if ((scalar @$conds != 1) || (scalar @$retkeys != 2)) {
-		log(L_ERR, "perlvdb:Auth: Broken column count requested. Unknown behavior. Desperately exiting.\n");
-		return undef;
-	}
-
-	for my $c (@$conds) {
-		$username = $c->data();
-	}
-
-	for my $k (@$retkeys) {
-		push @cols, new OpenSER::VDB::Column(DB_STRING, $k);
-	}
-
-	my $vtab = $self->{vtabs}->{$self->{tablename}};
-	$password = $vtab->call("query", $username);
-	
-	my $result;
-
-	if ($password) {
-		my @row;
-		push @row, new OpenSER::VDB::Value(DB_STRING, $password);
-		push @row, undef;
-		$result = new OpenSER::VDB::Result(\@cols, (bless \@row, "OpenSER::Utils::Debug"));
-	} else {
-		$result = new OpenSER::VDB::Result(\@cols);
-	}
-
-	return $result;
-}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/Describe.pm b/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/Describe.pm
deleted file mode 100644
index 98dddd2..0000000
--- a/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/Describe.pm
+++ /dev/null
@@ -1,143 +0,0 @@
-#
-# $Id: Describe.pm 757 2007-01-05 10:56:28Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2007 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-=head1 OpenSER::VDB::Adapter::Describe
-
-This package is intended for debug usage. It will print information about requested
-functions and operations of a client module.
-
-Use this module to request schema information when creating new adapters.
-
-=cut
-
-package OpenSER::VDB::Adapter::Describe;
-
-use OpenSER::Constants;
-use OpenSER qw ( log );
-
-use OpenSER::VDB;
-use OpenSER::VDB::Column;
-use OpenSER::VDB::Result;
-
-use Data::Dumper;
-
-our @ISA = qw ( OpenSER::VDB );
-
-sub use_table {
-	my $self = shift;
-	my $t = shift;
-
-	log(L_INFO, "About to use table $t\n");
-	return 0;
-}
-
-sub insert {
-	my $self = shift;
-	my $pairs = shift;
-
-	my $pairs_descr;
-
-	for my $p (@$pairs) {
-		$pairs_descr .= " (key = '".$p->key()."' type = '".$p->type()."' value = '".$p->data()."')";
-	}
-
-	log(L_INFO, "perlvdb:Describe: An insert was found with the following data: $pairs_descr\n");
-
-	return 0;
-	
-}
-
-sub replace {
-	my $self = shift;
-	return $self->insert(@_);
-}
-
-sub update {
-	my $self = shift;
-	
-	my $conds = shift;
-	my $pairs = shift;
-
-	my $cond_descr;
-	my $pairs_descr;
-
-	for my $c (@$conds) {
-		$cond_descr .= " (key = '".$c->key()."' op = '".$c->op()."' data = '".$c->data()."')";
-	}
-
-	log(L_INFO, "perlvdb:Describe: An update was found with the following conditions: $cond_descr\n");
-
-	for my $p (@$pairs) {
-		$pairs_descr .= " (key = '".$p->key()."' type = '".$p->type()."' value = '".$p->data()."')";
-	}
-
-	log(L_INFO, "perlvdb:Describe: The following data are to be updated: $pairs_descr\n");
-
-	return 0;
-}
-
-sub delete {
-	my $self = shift;
-
-	my $conds = shift;
-	my $cond_descr;
-
-	for my $c (@$conds) {
-		$cond_descr .= " (key = '".$c->key()."' op = '".$c->op()."' data = '".$c->data()."')";
-	}
-	
-	log(L_INFO, "perlvdb:Describe: A delete was found with the following conditions: $cond_descr\n");
-
-	return 0;
-}
-
-sub query {
-	my $self = shift;
-
-	my $conds = shift;
-	my $retkeys = shift;
-	my $order = shift;
-
-	my $cond_descr;
-	my $keys_descr;
-	my @cols;
-
-	for my $c (@$conds) {
-		$cond_descr .= " (key = '".$c->key()."' op = '".$c->op()."' data = '".$c->data()."')";
-	}
-	
-	log(L_INFO, "perlvdb:Describe: A query was found with the following conditions: $cond_descr\n");
-
-	for my $k (@$retkeys) {
-		$keys_descr .= " ($k)";
-		push @cols, new OpenSER::VDB::Column(DB_STRING, $k);
-	}
-	log(L_INFO, "perlvdb:Describe: The following keys were requested: $keys_descr\n");
-	log(L_INFO, "perlvdb:Describe: Order requested: '$order'\n");
-
-	return new OpenSER::VDB::Result(\@cols);
-}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/Speeddial.pm b/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/Speeddial.pm
deleted file mode 100644
index 8cf3b1b..0000000
--- a/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/Speeddial.pm
+++ /dev/null
@@ -1,82 +0,0 @@
-#
-# $Id: Speeddial.pm 757 2007-01-05 10:56:28Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2007 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-=head1 OpenSER::VDB::Adapter::Speeddial
-
-This adapter can be used with the speeddial module.
-
-=cut
-
-package OpenSER::VDB::Adapter::Speeddial;
-
-use OpenSER::Constants;
-use OpenSER qw ( log );
-
-use OpenSER::VDB;
-use OpenSER::VDB::Column;
-use OpenSER::VDB::Result;
-
-our @ISA = qw ( OpenSER::VDB );
-
-sub query {
-	my $self = shift;
-
-	my $conds = shift;
-	my $retkeys = shift; # Unused value here.
-	my $order = shift; # Unused value here.
-
-	my @cols;
-	
-	my $requested_username;
-	my $requested_sd_username;
-	
-	for my $c (@$conds) {
-		if (($c->key() eq "username") && ($c->op() eq "=")) {
-			$requested_username = $c->data();
-		}
-		if (($c->key() eq "sd_username") && ($c->op() eq "=")) {
-			$requested_sd_username = $c->data();
-		}
-	}
-
-	my $vtab = $self->{vtabs}->{$self->{tablename}};
-	$newaddr = $vtab->call("query", $requested_username, $requested_sd_username);
-	
-	my $result;
-
-	push @cols, new OpenSER::VDB::Column(DB_STRING, "uid_name");
-
-	if ($newaddr) {
-		my $resval = new OpenSER::VDB::Value(DB_STRING, $newaddr );
-		push my @row, $resval;
-		$result = new OpenSER::VDB::Result(\@cols, (bless \@row, "OpenSER::Utils::Debug"));
-	} else {
-		$result = new OpenSER::VDB::Result(\@cols);
-	}
-
-	return $result;
-}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/TableVersions.pm b/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/TableVersions.pm
deleted file mode 100644
index df06b32..0000000
--- a/modules_k/perl/lib/perl/OpenSER/VDB/Adapter/TableVersions.pm
+++ /dev/null
@@ -1,47 +0,0 @@
-#
-# $Id: TableVersions.pm 757 2007-01-05 10:56:28Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2007 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-package OpenSER::VDB::Adapter::TableVersions;
-
-use OpenSER;
-use OpenSER::Constants;
-
-sub version {
-	my $table = shift;
-
-	# FIXME We need to split table name again - possibly, this is a function only, so this one will not work
-	my $v = $table->version();
-
-	my @cols;
-	my @row;
-
-	push @cols, new OpenSER::VDB::Column(DB_INT, "table_version");
-	push @row, new OpenSER::VDB::Value(DB_INT, $v);
-	
-	return new OpenSER::VDB::Result(\@cols, (bless \@row, OpenSER::Utils::Debug));
-}
-
-1;
-
diff --git a/modules_k/perl/lib/perl/OpenSER/VDB/Column.pm b/modules_k/perl/lib/perl/OpenSER/VDB/Column.pm
deleted file mode 100644
index 119f825..0000000
--- a/modules_k/perl/lib/perl/OpenSER/VDB/Column.pm
+++ /dev/null
@@ -1,103 +0,0 @@
-#
-# $Id: Column.pm 852 2007-03-01 20:32:37Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2006 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-=head1 OpenSER::VDB::Column
-
-This package represents database column definition, consisting of a 
-column name and its data type.
-
-=head2 Stringification
-
-When accessing a OpenSER::VDB::Column object as a string, it simply returns its 
-column name regardless of its type.
-=cut
-
-package OpenSER::VDB::Column;
-
-use overload '""' => \&stringify;
-
-sub stringify { shift->{name} }
-
-use OpenSER;
-use OpenSER::Constants;
-
-our @ISA = qw ( OpenSER::Utils::Debug );
-
-=head2 new(type,name)
-
-Constructs a new Column object. Its type and the name are passed as
-parameters.
-
-=cut
-
-sub new {
-	my $class = shift;
-	my $type = shift;
-	my $name = shift;
-
-	my $self = {
-		type => $type,
-		name => $name,
-	};
-
-	bless $self, $class;
-
-	return $self;
-}
-
-
-=head2 type( )
-
-Returns or sets the current type. Please consider using the constants
-from OpenSER::Constants
-
-=cut
-
-sub type {
-	my $self = shift;
-	if (@_) {
-		$self->{type} = shift;
-	}
-
-	return $self->{type};
-}
-
-
-=head2 name()
-
-Returns or sets the current column name.
-
-=cut
-
-sub name {
-	my $self = shift;
-	if (@_) {
-		$self->{name} = shift;
-	}
-
-	return $self->{name};
-}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/VDB/Pair.pm b/modules_k/perl/lib/perl/OpenSER/VDB/Pair.pm
deleted file mode 100644
index c74f90c..0000000
--- a/modules_k/perl/lib/perl/OpenSER/VDB/Pair.pm
+++ /dev/null
@@ -1,78 +0,0 @@
-#
-# $Id: Pair.pm 757 2007-01-05 10:56:28Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2006 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-=head1 OpenSER::VDB::Pair
-
-This package represents database key/value pairs, consisting of a 
-key, a value type, and the value.
-
-This package inherits from OpenSER::VDB::Value and thus has the same methods.
-
-=cut
-
-package OpenSER::VDB::Pair;
-
-use OpenSER::VDB::Value;
-
-our @ISA = qw ( OpenSER::VDB::Value OpenSER::Utils::Debug );
-
-=head2 new(key,type,name)
-
-Constructs a new Column object.
-
-=cut
-
-sub new {
-	my $class = shift;
-	my $key = shift;
-	my $type = shift;
-	my $data = shift;
-
-	my $self = new OpenSER::VDB::Value($type, $data);
-
-	bless $self, $class;
-
-	$self->{key} = $key;
-
-	return $self;
-}
-
-
-=head2 key()
-
-Returns or sets the current key.
-
-=cut
-
-sub key {
-	my $self = shift;
-	if (@_) {
-		$self->{key} = shift;
-	}
-
-	return $self->{key};
-}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/VDB/ReqCond.pm b/modules_k/perl/lib/perl/OpenSER/VDB/ReqCond.pm
deleted file mode 100644
index feedac0..0000000
--- a/modules_k/perl/lib/perl/OpenSER/VDB/ReqCond.pm
+++ /dev/null
@@ -1,80 +0,0 @@
-#
-# $Id: ReqCond.pm 757 2007-01-05 10:56:28Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2006 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-=head1 OpenSER::VDB::ReqCond
-
-This package represents a request condition for database access, consisting of a 
-column name, an operator (=, <, >, ...), a data type and a value.
-
-This package inherits from OpenSER::VDB::Pair and thus includes its methods.
-
-=cut
-
-package OpenSER::VDB::ReqCond;
-
-use OpenSER::VDB::Value;
-use OpenSER::VDB::Pair;
-
-our @ISA = qw ( OpenSER::VDB::Pair OpenSER::Utils::Debug );
-
-=head2 new(key,op,type,name)
-
-Constructs a new Column object.
-
-=cut
-
-sub new {
-	my $class = shift;
-	my $key = shift;
-	my $op = shift;
-	my $type = shift;
-	my $data = shift;
-
-	my $self = new OpenSER::VDB::Pair($key, $type, $data);
-
-	bless $self, $class;
-
-	$self->{op} = $op;
-
-	return $self;
-}
-
-
-=head2 op()
-
-Returns or sets the current operator.
-
-=cut
-
-sub op {
-	my $self = shift;
-	if (@_) {
-		$self->{op} = shift;
-	}
-
-	return $self->{op};
-}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/VDB/Result.pm b/modules_k/perl/lib/perl/OpenSER/VDB/Result.pm
deleted file mode 100644
index b31eb50..0000000
--- a/modules_k/perl/lib/perl/OpenSER/VDB/Result.pm
+++ /dev/null
@@ -1,102 +0,0 @@
-#
-# $Id: Result.pm 852 2007-03-01 20:32:37Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2006 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-use strict;
-
-=head2 OpenSER::VDB::Result
-
-This class represents a VDB result set. It contains a
-column definition, plus an array of rows.
-Rows themselves are simply references to arrays of scalars.
-
-=cut
-
-package OpenSER::VDB::Result;
-
-use OpenSER;
-use OpenSER::VDB::Column;
-
-our @ISA = qw ( OpenSER::Utils::Debug );
-
-=head2 new(coldefs,[row, row, ...])
-
-The constructor creates a new Result object.
-Its first parameter is a reference to an array of
- OpenSER::VDB::Column objects.
-Additional parameters may be passed to provide initial rows, which
-are references to arrays of scalars.
-
-=cut
-
-sub new {
-	my $class = shift;
-	my $coldefs = shift;
-
-	my $self = {};
-
-	bless $self, $class;
-
-	$self->{coldefs} = $coldefs;
-
-	while (@_) {
-		push @{$self->{rows}}, shift;
-	}
-
-	return $self;
-}
-
-=head2 coldefs()
-
- Returns or sets the column definition of the object.
-
-=cut
-
-sub coldefs {
-	my $self = shift;
-
-	if (@_) {
-		$self->{coldefs} = shift;
-	}
-
-	return $self->{coldefs};
-}
-
-=head2 rows()
-
- Returns or sets the rows of the object.
-
-=cut
-
-sub rows {
-	my $self = shift;
-
-	while (@_) {
-		push @{$self->{rows}}, shift;
-	}
-
-	return $self->{rows};
-}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/VDB/VTab.pm b/modules_k/perl/lib/perl/OpenSER/VDB/VTab.pm
deleted file mode 100644
index 6e5da60..0000000
--- a/modules_k/perl/lib/perl/OpenSER/VDB/VTab.pm
+++ /dev/null
@@ -1,70 +0,0 @@
-#
-# $Id: VTab.pm 757 2007-01-05 10:56:28Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2006 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-=head1 OpenSER::VDB::VTab
-
-This package handles virtual tables and is used by the OpenSER::VDB class to store
-information about valid tables. The package is not inteded for end user access.
-
-=cut
-
-package OpenSER::VDB::VTab;
-
-use OpenSER;
-
-our @ISA = qw ( OpenSER::Utils::Debug );
-
-=head2 new()
-
- Constructs a new VTab object
-
-=cut
-
-sub new {
-	my $class = shift;
-	return bless { @_ }, $class;
-}
-
-=head2 call(op,[args])
-
-Invokes an operation on the table (insert, update, ...) with the
-given arguments.
-
-=cut
-
-sub call {
-	my $self = shift;
-	my $operation = shift;
-	my @args = @_;
-
-	if( my $obj = $self->{obj} ) {
-		return $obj->$operation(@args);
-	} else {
-		no strict;
-		return &{$self->{func}}($operation, @args);
-	}
-}
-
-1;
diff --git a/modules_k/perl/lib/perl/OpenSER/VDB/Value.pm b/modules_k/perl/lib/perl/OpenSER/VDB/Value.pm
deleted file mode 100644
index 9c8339e..0000000
--- a/modules_k/perl/lib/perl/OpenSER/VDB/Value.pm
+++ /dev/null
@@ -1,105 +0,0 @@
-#
-# $Id: Value.pm 852 2007-03-01 20:32:37Z bastian $
-#
-# Perl module for OpenSER
-#
-# Copyright (C) 2006 Collax GmbH
-#                    (Bastian Friedrich <bastian.friedrich@collax.com>)
-#
-# This file is part of Kamailio, a free SIP server.
-#
-# Kamailio is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version
-#
-# Kamailio is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-#
-
-=head1 OpenSER::VDB::Value
-
-This package represents a database value. Additional to the data itself,
-information about its type is stored.
-
-=head2 stringification
-
-When accessing a OpenSER::VDB::Value object as a string, it simply returns its data
-regardless of its type.
-=cut
-
-use strict;
-
-package OpenSER::VDB::Value;
-
-use overload '""' => \&stringify;
-
-sub stringify { shift->{data} }
-
-use OpenSER;
-use OpenSER::Constants;
-
-our @ISA = qw ( OpenSER::Utils::Debug );
-
-=head2 new(type,data)
-
-Constructs a new Value object. Its data type and the data are passed as
-parameters.
-
-=cut
-
-sub new {
-	my $class = shift;
-	my $type = shift;
-	my $data = shift;
-
-	my $self = {
-		type => $type,
-		data => $data,
-	};
-
-	bless $self, $class;
-
-	return $self;
-}
-
-
-=head2 type()
-
-Returns or sets the current data type. Please consider using the constants
-from OpenSER::Constants
-
-=cut
-
-sub type {
-	my $self = shift;
-	if (@_) {
-		$self->{type} = shift;
-	}
-
-	return $self->{type};
-}
-
-
-=head2 data()
-
-Returns or sets the current data.
-
-=cut
-
-sub data {
-	my $self = shift;
-	if (@_) {
-		$self->{data} = shift;
-	}
-
-	return $self->{data};
-}
-
-1;
diff --git a/modules_k/perl/perl.h b/modules_k/perl/perl.h
index 8905ca1..4f7d2ac 100644
--- a/modules_k/perl/perl.h
+++ b/modules_k/perl/perl.h
@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Perl module for OpenSER
+ * Perl module for Kamailio
  *
  * Copyright (C) 2006 Collax GmbH
  *                    (Bastian Friedrich <bastian.friedrich@collax.com>)
@@ -44,7 +44,7 @@ extern PerlInterpreter *my_perl;
 
 extern sl_api_t slb;
 
-#define PERLCLASS_MESSAGE	"OpenSER::Message"
-#define PERLCLASS_URI		"OpenSER::URI"
+#define PERLCLASS_MESSAGE	"Kamailio::Message"
+#define PERLCLASS_URI		"Kamailio::URI"
 
 #endif /* PERL_MOD_H */
diff --git a/modules_k/perl/perlfunc.c b/modules_k/perl/perlfunc.c
index f65b9c0..f4b592b 100644
--- a/modules_k/perl/perlfunc.c
+++ b/modules_k/perl/perlfunc.c
@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Perl module for OpenSER
+ * Perl module for Kamailio
  *
  * Copyright (C) 2006 Collax GmbH 
  *                    (Bastian Friedrich <bastian.friedrich@collax.com>)
@@ -128,7 +128,7 @@ int perl_exec2(struct sip_msg* _msg, char* fnc, char* mystr) {
 	}
 
 	m = sv_newmortal();
-	sv_setref_pv(m, "OpenSER::Message", (void *)_msg);
+	sv_setref_pv(m, "Kamailio::Message", (void *)_msg);
 	SvREADONLY_on(SvRV(m));
 
 
diff --git a/modules_k/perl/perlfunc.h b/modules_k/perl/perlfunc.h
index 95f9502..2d380b9 100644
--- a/modules_k/perl/perlfunc.h
+++ b/modules_k/perl/perlfunc.h
@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Perl module for OpenSER
+ * Perl module for Kamailio
  *
  * Copyright (C) 2006 Collax GmbH
  *                    (Bastian Friedrich <bastian.friedrich@collax.com>)
diff --git a/modules_k/perlvdb/perlvdb.h b/modules_k/perlvdb/perlvdb.h
index a356b5e..bf2d100 100644
--- a/modules_k/perlvdb/perlvdb.h
+++ b/modules_k/perlvdb/perlvdb.h
@@ -52,7 +52,7 @@
 #include "perlvdb_oohelpers.h"
 #include "perlvdbfunc.h"
 
-#define PERL_VDB_BASECLASS	"OpenSER::VDB"
+#define PERL_VDB_BASECLASS	"Kamailio::VDB"
 
 #define PERL_VDB_USETABLEMETHOD	"use_table"
 #define PERL_VDB_INSERTMETHOD	"_insert"
diff --git a/modules_k/perlvdb/perlvdb_conv.h b/modules_k/perlvdb/perlvdb_conv.h
index 2eb3235..a27f27c 100644
--- a/modules_k/perlvdb/perlvdb_conv.h
+++ b/modules_k/perlvdb/perlvdb_conv.h
@@ -35,9 +35,9 @@
 
 #include <XSUB.h>
 
-#define PERL_CLASS_VALUE	"OpenSER::VDB::Value"
-#define PERL_CLASS_PAIR		"OpenSER::VDB::Pair"
-#define PERL_CLASS_REQCOND	"OpenSER::VDB::ReqCond"
+#define PERL_CLASS_VALUE	"Kamailio::VDB::Value"
+#define PERL_CLASS_PAIR		"Kamailio::VDB::Pair"
+#define PERL_CLASS_REQCOND	"Kamailio::VDB::ReqCond"
 
 #define PERL_CONSTRUCTOR_NAME	"new"
 
diff --git a/modules_k/perl/perl.c b/modules_k/perl/perl.c
index 5e603ac..e527e1e 100644
--- a/modules_k/perl/perl.c
+++ b/modules_k/perl/perl.c
@@ -1,7 +1,7 @@
 /*
  * $Id$
  *
- * Perl module for OpenSER
+ * Perl module for Kamailio
  *
  * Copyright (C) 2006 Collax GmbH
  *                    (Bastian Friedrich <bastian.friedrich@collax.com>)
@@ -24,7 +24,7 @@
  *
  */
 
-#define DEFAULTMODULE "OpenSER"
+#define DEFAULTMODULE "Kamailio"
 #define MAX_LIB_PATHS 10
 
 #include <stdio.h>
@@ -53,7 +53,7 @@ MODULE_VERSION
 /* Full path to the script including executed functions */
 char *filename = NULL;
 
 /* Path to an arbitrary directory where the OpenSER Perl modules are
  * installed */
 char *modpath = NULL;
 
@@ -165,18 +165,18 @@ struct module_exports exports = {
 
 
 EXTERN_C void boot_DynaLoader (pTHX_ CV* cv);
-EXTERN_C void boot_OpenSER(pTHX_ CV* cv);
+EXTERN_C void boot_Kamailio(pTHX_ CV* cv);
 
 
 /*
  * This is output by perl -MExtUtils::Embed -e xsinit
- * and complemented by the OpenSER bootstrapping
+ * and complemented by the Kamailio bootstrapping
  */
 EXTERN_C void xs_init(pTHX) {
         char *file = __FILE__;
         dXSUB_SYS;
 
-        newXS("OpenSER::bootstrap", boot_OpenSER, file);
+        newXS("Kamailio::bootstrap", boot_Kamailio, file);
 
         newXS("DynaLoader::boot_DynaLoader", boot_DynaLoader, file);
 }
@@ -229,7 +229,7 @@ PerlInterpreter *parser_init(void) {
 		}
 	}
 
-	argv[argc] = "-M"DEFAULTMODULE; argc++; /* Always "use" Openser.pm */
+	argv[argc] = "-M"DEFAULTMODULE; argc++; /* Always "use" Kamailio.pm */
 
 	argv[argc] = filename; /* The script itself */
 	argc++;
@@ -314,7 +314,7 @@ struct mi_root* perl_mi_reload(struct mi_root *cmd_tree, void *param)
 
 /*
  * mod_init
  * Called by openser at init time
  */
 static int mod_init(void) {
 
@@ -356,7 +356,7 @@ static int mod_init(void) {
 
 /*
  * destroy
  * called by openser at exit time
  */
 static void destroy(void)
 {
@@ -53,7 +53,7 @@ MODULE_VERSION
 char *filename = NULL;
 
-/* Path to an arbitrary directory where the OpenSER Perl modules are
+/* Path to an arbitrary directory where the Kamailio Perl modules are
  * installed */
 char *modpath = NULL;
@@ -314,7 +314,7 @@ struct mi_root* perl_mi_reload(struct mi_root *cmd_tree, void *param)
 /*
  * mod_init
- * Called by openser at init time
+ * Called by kamailio at init time
  */
 static int mod_init(void) {
@@ -356,7 +356,7 @@ static int mod_init(void) {
 /*
  * destroy
- * called by openser at exit time
+ * called by kamailio at exit time
  */
 static void destroy(void)
diff --git a/modules_k/perlvdb/perlvdb_conv.c b/modules_k/perlvdb/perlvdb_conv.c
index c041c42..99dd752 100644
--- a/modules_k/perlvdb/perlvdb_conv.c
+++ b/modules_k/perlvdb/perlvdb_conv.c
@@ -62,7 +62,7 @@ AV *conds2perlarray(db_key_t* keys, db_op_t* ops, db_val_t* vals, int n) {
 					element = cond2perlcond(*(keys + i),
 							*(ops + i), vals + i);
 		} else {
 /* OP_EQ is defined in OpenSER _and_ perl. Includes collide :( */
 #ifdef OP_EQ
 			element = cond2perlcond(*(keys + i), OP_EQ, vals + i);
 #else
@@ -246,7 +246,7 @@ int perlresult2dbres(SV *perlres, db1_res_t **r) {
 			     modified db result value. */
 
 	if (!(SvROK(perlres) &&
-		(sv_derived_from(perlres, "OpenSER::VDB::Result")))) {
+		(sv_derived_from(perlres, "Kamailio::VDB::Result")))) {
 		goto error;
 	}
 	/* Memory allocation for C side result structure */
@@ -406,7 +406,7 @@ end:
 	av_undef(rowarray);
 	return retval;
 error:
-	LM_CRIT("broken result set. Exiting, leaving OpenSER in unknown state.\n");
+	LM_CRIT("broken result set. Exiting, leaving Kamailio in unknown state.\n");
 	return -1;
 }
 
@@ -62,7 +62,7 @@ AV *conds2perlarray(db_key_t* keys, db_op_t* ops, db_val_t* vals, int n) {
 							*(ops + i), vals + i);
 		} else {
-/* OP_EQ is defined in OpenSER _and_ perl. Includes collide :( */
+/* OP_EQ is defined in Kamailio _and_ perl. Includes collide :( */
 #ifdef OP_EQ
 			element = cond2perlcond(*(keys + i), OP_EQ, vals + i);
diff --git a/modules_k/perlvdb/perlvdbfunc.c b/modules_k/perlvdb/perlvdbfunc.c
index f7f162c..006e463 100644
--- a/modules_k/perlvdb/perlvdbfunc.c
+++ b/modules_k/perlvdb/perlvdbfunc.c
@@ -85,7 +85,7 @@ SV *getobj(db1_con_t *con) {
  * - not null
  * - not undef
  * - an object
- * - derived from OpenSER::VDB
+ * - derived from Kamailio::VDB
  */
 int checkobj(SV* obj) {
 	if (obj != NULL) {
@@ -314,13 +314,13 @@ int perlvdb_db_query(db1_con_t* h, db_key_t* k, db_op_t* op, db_val_t* v,
 	av_undef(condarr);
 	av_undef(retkeysarr);
 
 	/* Transform perl result set to OpenSER result set */
 	if (!resultset) {
 		/* No results. */
 		LM_ERR("no perl result set.\n");
 		retval = -1;
 	} else {
-		if (sv_isa(resultset, "OpenSER::VDB::Result")) {
+		if (sv_isa(resultset, "Kamailio::VDB::Result")) {
 			retval = perlresult2dbres(resultset, r);
 		/* Nested refs are decreased/deleted inside the routine */
 			SvREFCNT_dec(resultset);
@@ -314,13 +314,13 @@ int perlvdb_db_query(db1_con_t* h, db_key_t* k, db_op_t* op, db_val_t* v,
 	av_undef(retkeysarr);
 
-	/* Transform perl result set to OpenSER result set */
+	/* Transform perl result set to Kamailio result set */
 	if (!resultset) {
 		/* No results. */
